require_relative 'test_helper'

require 'thread'
require 'tmpdir'
require 'tempfile'
require 'fileutils'
require 'pathname'
require 'minitest/autorun'

require 'slog'


Thread.abort_on_exception = true



# Mostly for coverage, testing the utility functions.
class TestSlog < MiniTest::Test

  attr_reader :tmpdir, :logger


  def setup
    @tmpdir = Dir.mktmpdir
    @logger = Slog::Logger.new colorize: false, out: $stderr
    @logger.level = ::Logger::WARN
  end


  def teardown
    FileUtils.rm_rf tmpdir
  end


  def test_slog_logger_structure_event now=DateTime.now
    expected_event = {
      'level' => 'info',
      '@timestamp' => now.iso8601(3)
    }
    assert expected_event, logger.structure_event('info', now, {})
  end


  def test_slog_logger_format_json
    assert "{}\n", logger.format_json({}, 'info')
  end


  def test_slog_logger_formatter now=DateTime.now
    event = {
      'level' => 'info',
      '@timestamp' => now.iso8601(3)
    }
    expected_output = JSON.pretty_generate(event) + "\n"
    assert expected_output, logger.formatter.call('INFO', now, nil, {})
  end

  def test_slog_logger
    assert logger.info({})
  end
end